@@ -1,6 +1,7 @@
 use crate::event::bootloader_event::*;
 use crate::event::general_event::*;
 use crate::event::programmer_event::*;
+use crate::event::bcm_event::*;
 
 #[derive(Debug, PartialEq)]
 pub enum EventPacketError {
@@ -17,4 +18,6 @@ pub enum EventPacket {
 
     ProgrammerHello(ProgrammerHelloEvent),
     ProgrammerStartUpload(ProgrammerStartUploadEvent),
+
+    BcmChangeBrightness(BcmChangeBrightnessEvent)
 }
